==> rizin-src-v0.6.2.tar.xz: rizin-v0.6.2/librz/include/rz_il/rz_il_opbuilder_end.h <==

#ifndef RZ_IL_OPBUILDER_BEGIN_H
#error rz_il_opbuilder_end.h included without rz_il_opbuilder_begin.h before
#endif

#undef DUP
#undef ITE

#undef UN
#undef U8
#undef U16
#undef U32
#undef U48
#undef U64
#undef CAST
#undef BOOL_TO_BV

#undef SN
#undef S8
#undef S16
#undef S32
#undef S64

#undef BV2F
#undef F32
#undef F64
#undef F2BV
#undef IS_FINITE
#undef IS_FNAN
#undef IS_FINF
#undef IS_FZERO
#undef IS_FNEG
#undef IS_FPOS
#undef FNEG
#undef FABS
#undef F2INT
#undef F2SINT
#undef INT2F
#undef SINT2F
#undef FCONVERT
#undef FLOATV16
#undef FLOATV32
#undef FLOATV64
#undef FLOATV128
#undef FSUCC
#undef FPRED
#undef FORDER
#undef FROUND
#undef FSQRT
#undef FADD
#undef FSUB
#undef FMUL
#undef FDIV
#undef FMOD
#undef FPOW
#undef FMAD
#undef FNEQ
#undef FEQ

#undef IL_FALSE
#undef IL_TRUE
#undef INV
#undef XOR
#undef AND

#undef UNSIGNED
#undef SIGNED
#undef APPEND

#undef ADD
#undef SUB
#undef MUL
#undef DIV
#undef SDIV
#undef MOD
#undef SMOD
#undef SHIFTL
#undef SHIFTR
#undef SHIFTL0
#undef SHIFTR0
#undef SHIFTRA
#undef LOGAND
#undef LOGOR
#undef LOGXOR
#undef LOGNOT
#undef NEG

#undef NON_ZERO
#undef IS_ZERO
#undef MSB
#undef LSB
#undef EQ
#undef UGT
#undef ULT
#undef ULE
#undef UGT
#undef UGE
#undef SLT
#undef SLE
#undef SGT
#undef SGE

#undef LOAD
#undef LOADW
#undef STORE
#undef STOREW

#undef VARG
#undef VARL
#undef VARLP
#undef SETG
#undef SETL
#undef LET

#undef SEQ2
#undef SEQ3
#undef SEQ4
#undef SEQ5
#undef SEQ6
#undef SEQ7
#undef SEQ8
#undef SEQ9
#undef SEQN

#undef EMPTY
#undef NOP
#undef BRANCH
#undef REPEAT
#undef JMP
#undef GOTO

#undef RZ_IL_OPBUILDER_BEGIN_H

==> rizin-src-v0.8.1.tar.xz: rizin-v0.8.1/librz/include/rz_il/rz_il_opbuilder_end.h <==

#ifndef RZ_IL_OPBUILDER_BEGIN_H
#error rz_il_opbuilder_end.h included without rz_il_opbuilder_begin.h before
#endif

#undef DUP
#undef ITE

#undef UN
#undef U8
#undef U16
#undef U32
#undef U48
#undef U64
#undef CAST
#undef BOOL_TO_BV

#undef SN
#undef S8
#undef S16
#undef S32
#undef S64

#undef BV2F
#undef F32
#undef F64
#undef F80
#undef F2BV
#undef IS_FINITE
#undef IS_FNAN
#undef IS_FINF
#undef IS_FZERO
#undef IS_FNEG
#undef IS_FPOS
#undef FNEG
#undef FABS
#undef F2INT
#undef F2SINT
#undef INT2F
#undef SINT2F
#undef FCONVERT
#undef FLOATV16
#undef FLOATV32
#undef FLOATV64
#undef FLOATV128
#undef FSUCC
#undef FPRED
#undef FORDER
#undef FROUND
#undef FSQRT
#undef FADD
#undef FSUB
#undef FMUL
#undef FDIV
#undef FMOD
#undef FPOW
#undef FMAD
#undef FNE
#undef FEQ
#undef FLT
#undef FLE
#undef FGE
#undef FGT

#undef IL_FALSE
#undef IL_TRUE
#undef INV
#undef XOR
#undef AND

#undef UNSIGNED
#undef SIGNED
#undef APPEND

#undef ADD
#undef SUB
#undef MUL
#undef DIV
#undef SDIV
#undef MOD
#undef SMOD
#undef SHIFTL
#undef SHIFTR
#undef SHIFTL0
#undef SHIFTR0
#undef SHIFTRA
#undef LOGAND
#undef LOGOR
#undef LOGXOR
#undef LOGNOT
#undef NEG

#undef NON_ZERO
#undef IS_ZERO
#undef MSB
#undef LSB
#undef EQ
#undef NE
#undef UGT
#undef ULT
#undef ULE
#undef UGT
#undef UGE
#undef SLT
#undef SLE
#undef SGT
#undef SGE

#undef LOAD
#undef LOADW
#undef STORE
#undef STOREW

#undef VARG
#undef VARL
#undef VARLP
#undef SETG
#undef SETL
#undef LET

#undef SEQ2
#undef SEQ3
#undef SEQ4
#undef SEQ5
#undef SEQ6
#undef SEQ7
#undef SEQ8
#undef SEQ9
#undef SEQN

#undef EMPTY
#undef NOP
#undef BRANCH
#undef REPEAT
#undef JMP
#undef GOTO

#undef NOT_IMPLEMENTED

#undef EXTRACT32
#undef EXTRACT64
#undef SEXTRACT32
#undef SEXTRACT64
#undef DEPOSIT32
#undef DEPOSIT64
#undef BSWAP16
#undef BSWAP32
#undef BSWAP64

#undef RZ_IL_OPBUILDER_BEGIN_H
